// Sticky Plugin v1.0.0 for jQuery
// =============
// Author: Anthony Garand
// Improvements by German M. Bravo (Kronuz) and Ruud Kamphuis (ruudk)
// Improvements by Leonardo C. Daronco (daronco)
// Created: 2/14/2011
// Date: 2/12/2012
// Website: http://labs.anthonygarand.com/sticky
// Description: Makes an element on the page stick on the screen as you scroll
//       It will only set the 'top' and 'position' of your element, you
//       might need to adjust the width in some cases.

(function($) {
  var defaults = {
      topSpacing: 0,
      bottomSpacing: 0,
      className: 'is-sticky',
      wrapperClassName: 'sticky-wrapper',
      center: false,
      getWidthFrom: '',
      responsiveWidth: false
    },
    $window = $(window),
    $document = $(document),
    sticked = [],
    windowHeight = $window.height(),
    scroller = function() {
      var scrollTop = $window.scrollTop(),
        documentHeight = $document.height(),
        dwh = documentHeight - windowHeight,
        extra = (scrollTop > dwh) ? dwh - scrollTop : 0;

      for (var i = 0; i < sticked.length; i++) {
        var s = sticked[i],
          elementTop = s.stickyWrapper.offset().top,
          etse = elementTop - s.topSpacing - extra;

        if (scrollTop <= etse) {
          if (s.currentTop !== null) {
            s.stickyElement
              .css('position', '')
              .css('top', '');
            s.stickyElement.trigger('sticky-end', [s]).parent().removeClass(s.className);
            s.currentTop = null;
          }
        }
        else {
          var newTop = documentHeight - s.stickyElement.outerHeight()
            - s.topSpacing - s.bottomSpacing - scrollTop - extra;
          if (newTop < 0) {
            newTop = newTop + s.topSpacing;
          } else {
            newTop = s.topSpacing;
          }
          if (s.currentTop != newTop) {
            s.stickyElement
              .css('position', 'fixed')
              .css('top', newTop);

            if (typeof s.getWidthFrom !== 'undefined') {
              s.stickyElement.css('width', $(s.getWidthFrom).width());
            }

            s.stickyElement.trigger('sticky-start', [s]).parent().addClass(s.className);
            s.currentTop = newTop;
          }
        }
      }
    },
    resizer = function() {
      windowHeight = $window.height();

      for (var i = 0; i < sticked.length; i++) {
        var s = sticked[i];
        if (typeof s.getWidthFrom !== 'undefined' && s.responsiveWidth === true) {
          s.stickyElement.css('width', $(s.getWidthFrom).width());
        }
      }
    },
    methods = {
      init: function(options) {
        var o = $.extend({}, defaults, options);
        return this.each(function() {
          var stickyElement = $(this);

          var stickyId = stickyElement.attr('id');
          var wrapperId = stickyId ? stickyId + '-' + defaults.wrapperClassName : defaults.wrapperClassName 
          var wrapper = $('<div></div>')
            .attr('id', stickyId + '-sticky-wrapper')
            .addClass(o.wrapperClassName);
          stickyElement.wrapAll(wrapper);

          if (o.center) {
            stickyElement.parent().css({width:stickyElement.outerWidth(),marginLeft:"auto",marginRight:"auto"});
          }

          if (stickyElement.css("float") == "right") {
            stickyElement.css({"float":"none"}).parent().css({"float":"right"});
          }

          var stickyWrapper = stickyElement.parent();
          stickyWrapper.css('height', stickyElement.outerHeight());
          sticked.push({
            topSpacing: o.topSpacing,
            bottomSpacing: o.bottomSpacing,
            stickyElement: stickyElement,
            currentTop: null,
            stickyWrapper: stickyWrapper,
            className: o.className,
            getWidthFrom: o.getWidthFrom,
            responsiveWidth: o.responsiveWidth
          });
        });
      },
      update: scroller,
      unstick: function(options) {
        return this.each(function() {
          var unstickyElement = $(this);

          var removeIdx = -1;
          for (var i = 0; i < sticked.length; i++)
          {
            if (sticked[i].stickyElement.get(0) == unstickyElement.get(0))
            {
                removeIdx = i;
            }
          }
          if(removeIdx != -1)
          {
            sticked.splice(removeIdx,1);
            unstickyElement.unwrap();
            unstickyElement.removeAttr('style');
          }
        });
      }
    };

  // should be more efficient than using $window.scroll(scroller) and $window.resize(resizer):
  if (window.addEventListener) {
    window.addEventListener('scroll', scroller, false);
    window.addEventListener('resize', resizer, false);
  } else if (window.attachEvent) {
    window.attachEvent('onscroll', scroller);
    window.attachEvent('onresize', resizer);
  }

  $.fn.sticky = function(method) {
    if (methods[method]) {
      return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
    } else if (typeof method === 'object' || !method ) {
      return methods.init.apply( this, arguments );
    } else {
      $.error('Method ' + method + ' does not exist on jQuery.sticky');
    }
  };

  $.fn.unstick = function(method) {
    if (methods[method]) {
      return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
    } else if (typeof method === 'object' || !method ) {
      return methods.unstick.apply( this, arguments );
    } else {
      $.error('Method ' + method + ' does not exist on jQuery.sticky');
    }

  };
  $(function() {
    setTimeout(scroller, 0);
  });
})(jQuery);



/** 
 * JS Code for the DC LIGHT theme
 */

$(document).ready(function () {

	/* HOUSE CLEANING */
	// declare that we're using js //
	$('html').addClass('js');

	// fix menu items //
	$('.DCMainMenubar .DCMainMenuItem a').each(function() {
		if ($(this).text() === ' Mobile') { $(this).parent().remove(); }
		if ($(this).text() === 'List') { $(this).text("List View"); }
		if ($(this).text() === 'Why') { $(this).parent().html($(this).text('Why Dancecal?')); }
		if ($(this).text() === 'Add Event') { $(this).parent().html($(this).text('Add Event')); $(this).addClass('DCAddEvent')}
	});

	// clear nonbreaking spaces in calendar //
	// it's messing with the filtering script in that the rows won't auto-collapse when no event is in them anymore //
	$('.DCDay.DCDayMiddleEmpty').html('');
	$('.DCDay.DCDayMiddle').html('');
	$('.DCDay.DCDayBottomEmpty').html('');
	$('.DCDay.DCDayBottom').html('');

	// clean up map button and move it to the menu
	$('.DCMap br').remove();
	var map = $('.DCMap');
	$('.DCMenu').prepend(map);
	$('.DCMap a i b').append(" &rarr;");
	$('.DCMap').show();

	// redo type icons //
	$('.DCEventName > img').each(function() {
		var type;
		var typecode = $(this).attr('alt');
		if (typecode === 'W') {
			type = 'Workshop';
		} else if (typecode === 'E') {
			typecode = 'X';
			type = 'Exchange';
		} else if (typecode === 'H') {
			typecode = 'P';
			type = 'HouseParty';
		}
		$(this).parent().find(".DCDanceIcons").prepend("<div class='DCTypeIcon DC" + type + "'>" + typecode + "</div>");

		$(this).remove();
	});

	// rename dance icons //
	$('.DCDanceIcon.DCBlues').text('Blues');
	$('.DCDanceIcon.DCLindy').text('Lindy');
	$('.DCDanceIcon.DCBluesLindy').hide();
	$('.DCDanceIcon.DCBalboa').text('Balboa');
	$('.DCDanceIcon.DCShag').text('Shag');
	$('.DCDanceIcon.DCTango').text('Tango');
	$('.DCDanceIcon.DCFusion').text('Fusion');
	$('.DCDanceIcon.DCWest_Coast').text('WCS');
	$('.DCDanceIcon.DCSolo_Jazz').text('Solo Jazz');
	$('.DCDanceIcon.DCOther').text('Other');
	$('.DCDanceIcon.DCHoliday').hide();

	// label the actual name of .DCEventName
	// idk what to do if it isn't a link..
	$('.DCEventName a').addClass('DCEventNameName');

	// reorganize .DCEventInfo pieces
	$('.DCEventInfoDate').each(function() {
		$(this).parent().append($(this));
		$(this).prepend("Date: ");
	});

	// class the .DCEventInfoButton spans //
	$('.DCEventInfoFacebook').addClass('DCEventInfoButton');
	$('.DCEventInfoGCal').addClass('DCEventInfoButton');

	// change .DCEventButton image source //
	$('.DCEventInfoGCal a img').remove();
	$('.DCEventInfoGCal a').append("<img src='DanceCal.com_files/calendar.16.png' alt='GCal' height='16' width='16' title='Add to Google Calendar'>");
	$('.DCEventInfoFacebook a img').remove();
	$('.DCEventInfoFacebook a ').append("<img src='DanceCal.com_files/facebook.16.png' alt='Facebook' height='16' width='16' title='View on Facebook'>");

	// add the link button //
	$('.DCEvent').each(function(){
		var link = $(this).find('.DCEventNameName').attr('href');
		$(this).find('.DCEventInfo').prepend("<span class='DCEventInfoLink DCEventInfoButton'><a href='" + link + "' target='_blank'><img src='DanceCal.com_files/link.16.png' alt='Facebook' height='16' width='16' title='Go to Website'></a></span>");
	});

	// remove Return to Top divs//
	$('.DCCalendar > div:contains("Return to ")').remove();



	/* MAIN MENU */
	// make main menu collapse //
	$('.DCMainMenubar').before("<div class='DCMainMenuLabel'><a href='#'>&equiv; Menu</a></div>").slideUp();
	$('.DCMainMenuLabel').click(function(){
		$('.DCMainMenubar').slideToggle();
		return false;
	});

	// make config menu collapse //
	$('.DCConfigMenu').before("<div class='DCConfigMenuLabel'><a href='#'>&equiv; Show More Options</a></div>").slideUp();
	$('.DCConfigMenuLabel').click(function(){
		$('.DCConfigMenu').slideToggle();
		return false;
	});

	// minor style changes //
	$('.DCMenuGo a').addClass('button');


	// style map with icon //
//	$('.DCMap a').prepend('🌎'); // doesn't work (not set to unicode?);


	/* EVENT POPuPS */	


	/* TAG MENU ************************************************************************************************/
	$('.DCMenuKey').contents().remove();
	var dancesLabels = { Blues  : "Blues",
					     Lindy  : "Lindy Hop",
					     Balboa : "Balboa",
					     Shag   : "Shag",
					     Tango  : "Tango",
					     Fusion : "Fusion",
					     West_Coast : "WCS",
					     Solo_Jazz : "Solo Jazz",
					     Other : "Other" }

	var dancesActive = { Blues  : true,
					     Lindy  : true,
					     Balboa : true,
					     Shag   : true,
					     Tango  : true,
					     Fusion : true,
					     West_Coast : true,
					     Solo_Jazz : true,
					     Other : true }

    $.each(dancesLabels, function(key, value){
		$('.DCMenuKey').append("<div class='DCDanceChoiceWidget DC" + key + "' id='DC" + key + "'><span class='DCDanceChoiceWidgetLabel clickable'>" + value + "</span></div>");
    });
    $('.DCMenuKey').slideDown();

	$('.DCDanceChoiceWidget').prepend('<span class="DCDanceChoiceWidgetButton No clickable">&cross;</span>');
	$('.DCDanceChoiceWidget').prepend('<span class="DCDanceChoiceWidgetButton Yes clickable active">&check;</span>');


	$('.DCEventName').each(function() {
		if ($(this).next().hasClass('DCEventInfo')) {
			$(this).append('<span class="DCToggleArrow">&darr;</span>');
			$(this).click(function(){
				toggleEventInfo($(this).parent());
				return false;
			});
			$(this).addClass('clickable');
		}
	});

	$('.DCMenuKey').append('<div class="DCMenuKeyOutput">...</div>');
	updateKeyOutput(dancesActive, dancesLabels);

	$('.DCDanceChoiceWidgetLabel').click(function(){
		/* get "this dance" */
		var danceName = $(this).parent().attr('id').replace('DC','');
		
		// set everything else to indifferent
		$('.DCMenuKey .DCDanceChoiceWidgetButton').removeClass('active')
		dancesActive = {}

		// set this to 'yes'
		$('.DCDanceChoiceWidget.DC' + danceName + ' .DCDanceChoiceWidgetButton.Yes').addClass('active');
		dancesActive[danceName] = true;

		console.log(dancesActive);

		/* toggle events */
		updateEvents(dancesActive);

		/* update menu output */
		updateKeyOutput(dancesActive, dancesLabels);
	})

	$('.DCDanceChoiceWidgetButton').click(function(){
		/* get "this dance" */
		var danceName = $(this).parent().attr('id').replace('DC','');

		// check if 'yes' or 'no'
		if ($(this).hasClass('Yes')) {			

			/* toggle icon */
			if ($(this).hasClass('active')) {
				$(this).removeClass('active');
				delete dancesActive[danceName];
			} else {
				$(this).addClass('active');
				$(this).siblings('.DCDanceChoiceWidgetButton').removeClass('active');;
				dancesActive[danceName] = true;
			}
		} else if ($(this).hasClass('No')) {			

			/* toggle icon */
			if ($(this).hasClass('active')) {
				$(this).removeClass('active');
				delete dancesActive[danceName];
			} else {
				$(this).addClass('active');
				$(this).siblings('.DCDanceChoiceWidgetButton').removeClass('active');;
				dancesActive[danceName] = false;
			}
		}


		/* toggle events */
		updateEvents(dancesActive);

		/* update menu output */
		updateKeyOutput(dancesActive, dancesLabels);

	});


	/* STICKY THINGS */
	// month header //
	$('.DCMonthHeader').sticky({topSpacing:0});

	// days of the week //
	$('.DCWeek:nth-child(2)').sticky({topSpacing: 30});

	// side menu (but only when its a side menu //
	if ($(window).width() >= 1000 && $(window).height() >= $('.DCMenu').height()) {
		$('.DCMenu').sticky({topSpacing: 0, wrapperClassName: 'LIGHTMenuStickyWrapper'});
	}

	$(window).resize(function(){
		if ($(window).width() >= 1000 && $(window).height() >= $('.DCMenu').height()) {
			if (! $('.LIGHTMenuStickyWrapper').length) {
				$('.DCMenu').sticky({topSpacing: 0, wrapperClassName: 'LIGHTMenuStickyWrapper'});
				$('.DCMenu').sticky('update');
			}
		} else {
			$('.DCMenu').unstick();
		}
	});

	/* HELP ALERTBAR */
	$('body').prepend('<div class="alertbar"> '
					  + '<button class="dismiss-button">&cross;</button>'
					  + "<span class='title'>Welcome to Dancecal's newest skin: <span class='highlight'>DC Light</span></span><br>"
					  + "You can use the tags below to fine-tune your search.<br>"
					  + "<br>"
					  + "<div class='more-info'>"
					    + "<div class='DCDanceChoiceWidget DCOther' id='DCOther'>"
						+ '<span class="DCDanceChoiceWidgetButton Yes  active">&check;</span>'
					  	+ '<span class="DCDanceChoiceWidgetButton No ">&cross;</span>'
					  	+ "<span class='DCDanceChoiceWidgetLabel '>Example</span></div>"
					  	+ "<div class='hint'>Display all events containing this tag</div>"
					  	+ "<br>"
					    + "<div class='DCDanceChoiceWidget DCOther' id='DCOther'>"
						+ '<span class="DCDanceChoiceWidgetButton Yes ">&check;</span>'
					  	+ '<span class="DCDanceChoiceWidgetButton No  active">&cross;</span>'
					  	+ "<span class='DCDanceChoiceWidgetLabel '>Example</span></div>"
					  	+ "<div class='hint'>Don't display an event if it contains this tag</div>"
					  	+ "<br>"
					    + "<div class='DCDanceChoiceWidget DCOther' id='DCOther'>"
						+ '<span class="DCDanceChoiceWidgetButton Yes ">&check;</span>'
					  	+ '<span class="DCDanceChoiceWidgetButton No ">&cross;</span>'
					  	+ "<span class='DCDanceChoiceWidgetLabel '>Example</span></div>"
					  	+ "<div class='hint'>This tag does not affect the search query</div>"
					  + "</div>"
					  + "<a id='learn-more-button' class='button' href='#'>Learn more &darr;</a>"
					  + '</div>');
	$('.alertbar').slideDown();
	$('.alertbar .dismiss-button').click(function() {
		$(this).parent().slideUp();
	});
	$('#learn-more-button').click(function(){
		$('.more-info').slideDown(function(){
			$('#learn-more-button').slideUp();
		});
		return false;
	});



	// use CONTAINS(), it'll be quicker --- don't know the implimentation
	/* HIDE / SHOW Events */
	var visibleRowsDefault = 4; // amount of rows/week to show as a default
	var count = 0;
	var tempWeekStorage = "";

	// label weeks like they should be
	$('.DCWeek').each(function() {
		var events = 0;
		var isEvent = false;
		var isWeekStart = false;
		var isBottom = false;

		$(this).children('.DCDayNumber').each(function() {
			isWeekStart = true;
		});

		$(this).children('.DCEvent:visible').each(function() {
			isEvent = true;
			events ++;
		});
// for end of week

		if (isWeekStart) {
			$(this).addClass('LIGHTWeekStart');
		}

		if (isEvent) {
			$(this).addClass('LIGHTEventWeek');
			$(this).addClass(events);
		}

		if (isBottom) {

			/// DO something with this
		}
	})

/*	$('.DCEvent').each(function() {
		count++;

		if (count > visibleRowsDefault) {
			$(this).slideUp();
		}

//		if ($(this).contains('.DCNoBorder') || $(this).contains('.DCDayNumber')) {
			// do nothing
//		} else { 
			// collapse row 
//			$(this).slideUp();
//		}
	});
*/

	/* FUNCTIONS */
	function toggleEventInfo(eventWrapper) {
		if (eventWrapper.children(".DCEventInfo").is(":visible")) {
			eventWrapper.children(".DCEventInfo").slideToggle(function (){ 
				eventWrapper.removeClass('open');
				eventWrapper.children(".DCEventName").children(".DCToggleArrow").html("&darr;");
			});
		} else {
			eventWrapper.addClass('open');
			eventWrapper.children(".DCEventInfo").slideToggle(function() {
				eventWrapper.children(".DCEventName").children(".DCToggleArrow").html("&uarr;");
			});
		}
	}

	/** 
	 * We can show more meta information, like: 
	 * how many events we're showing and 
	 * have better lists
	 * clean up the unecessary commas, etc.
	 * add a ", and" to the last ones..
	 * display style color tag with name as well
	 * don't display a begining phrase if there's nothing to put behind it
	 */
	function updateKeyOutput(dancesActive, dancesLabels) {
		var output = "";
		var allEvents = true;

		output += "show events containing ";
		for (var dance in dancesLabels) {
			if (dancesActive[dance] === true) {
				output += "<strong>" + dancesLabels[dance] + "</strong>, ";
			} else {
				allEvents = false;
			}
		}
		output += ".<br>";

		output += "do not show events containing ";
		for (var dance in dancesLabels) {
			if (dancesActive[dance] === false) {
				output += "<strong>" + dancesLabels[dance] + "</strong>, ";
				allEvents = false;
			}
		}
		output += ".<br>";

		if (allEvents) { output = "show all events.<br>"; }

		$('.DCMenuKeyOutput').html(output);
	}

	function updateEvents(dancesActive) {
	// go through DCEvents and make sure there is at least one similar tag dancesActive
	$('.DCEvent').each(function(){
		// determine if we should show the event
		var show = false;
		for (var dance in dancesActive) {
			if (dancesActive[dance] === false && $(this).hasClass('DC'+dance)) {
				show = false;
				break;
			} else if (dancesActive[dance] && $(this).hasClass('DC'+dance)) {
				show = true;
			}
		}

		// replace this with something of the same size in case there is something else that same week-row that is keeping it visible
		// otherwise the day borders will get off 
		if (show) {
			$(this).next('.LIGHTGapFiller').remove();
			$(this).next('.LIGHTGapFiller').remove();
			$(this).next('.LIGHTGapFiller').remove();
			$(this).next('.LIGHTGapFiller').remove();
			$(this).next('.LIGHTGapFiller').remove();
			$(this).next('.LIGHTGapFiller').remove();
			$(this).next('.LIGHTGapFiller').remove();// try seven times because there could conceivably, be seven gap fillers
			$(this).show();
		} else {
			if ($(this).is(":visible")) {
				$(this).hide();
				var classes = $(this).attr('class');
				var daySpanIndex = classes.indexOf("DCDaySpan");
				var daySpan = classes.substr(daySpanIndex+9, 1); // first param is length of "DCDaySpan"
				console.log(daySpan);

				// construct days //
	//			$(this).after("<div class='DCDay DCEvent LIGHTGapFiller DCDaySpan" + daySpan + "'></div>");


				var gapFiller = "";
				for (var day = 0; day < daySpan; day ++) {
					gapFiller += "<div class='DCDay DCDayMiddle LIGHTGapFiller'></div>";
				}

				$(this).after(gapFiller);
			}
		}
	});

}

});
